"""Django-filter integration for django-admin-deux."""

# Re-export Filter and Order from djadmin for convenience
from djadmin import Filter, Order

__version__ = '0.1.0'

# Default Django app configuration
default_app_config = 'djadmin_filters.apps.DjAdminFiltersConfig'

__all__ = ['Filter', 'Order']
